--[[
    Core.lua
    
    Core file for CombatDnd
    
    Author: Borlox
]]--

CombatDnd = AceLibrary("AceAddon-2.0"):new("AceConsole-2.0", "AceEvent-2.0", "AceDB-2.0")

local Waterfall = AceLibrary("Waterfall-1.0")
local L = AceLibrary("AceLocale-2.2"):new("CombatDnd")

------

CombatDnd.Options = {
  type = "group",
  args = {
    text = {
      type  = "text",
      name  = L["Text"],
      desc  = L["Change your dnd text."],
      usage = L["<Text>"],
      get   = "GetText",
      set   = "SetText",
    },
    config  = {
      type  = "execute",
      desc  = L["Open the config menu."],
      name  = L["Config"],
      func  = "Config",
    }
  },
}

CombatDnd:RegisterDB("CombatDndDB", "CombatDndDBPC")
CombatDnd:RegisterDefaults("profile", {
  text = L["DEFAULT_TEXT"],
})

------

function CombatDnd:OnInitialize()
  self:RegisterChatCommand(L["SLASH_CMD"], self.Options)
  
  Waterfall:Register(self.name,
    "title", L["CombatDnd Configuration"],
    "aceOptions", self.Options,
    "colorR", 1,
    "colorG", 0.2,
    "colorB", 0.2)
end

function CombatDnd:OnEnable()
  self:RegisterEvent("PLAYER_REGEN_DISABLED")
  self:RegisterEvent("PLAYER_REGEN_ENABLED")
end

function CombatDnd:OnDisable()
  self:UnregisterAllEvents()
end

------

function CombatDnd:PLAYER_REGEN_DISABLED()
  if not UnitIsDND("player") then
    SendChatMessage(self.db.profile.text, "DND")
  else
    self.ChangeDnd = nil
  end
end

function CombatDnd:PLAYER_REGEN_ENABLED()
  if UnitIsDND("player") and self.ChangeDnd then
    SendChatMessage("", "DND")
  end
  self.ChangeDnd = 1
end

------

function CombatDnd:GetText()
  return self.db.profile.text
end

function CombatDnd:SetText(new)
  if (new == "") or (new == "DEFAULT") then
    new = L["DEFAULT_TEXT"]
  end
  
  self.db.profile.text = new
end

function CombatDnd:Config()
  Waterfall:Open(self.name)
end